==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/dc/d7a/structEngine.js <==
var structEngine =
[
    [ "Engine", "dc/d7a/structEngine.html#a8c98683b0a3aa28d8ab72a8bcd0d52f2", null ],
    [ "Engine", "dc/d7a/structEngine.html#ab982bcd16c14f30e70dfd0135b879cd4", null ],
    [ "~Engine", "dc/d7a/structEngine.html#a8ef7030a089ecb30bbfcb9e43094717a", null ],
    [ "CanCarryCargo", "dc/d7a/structEngine.html#ae398bf3ad2c3ba475880fc7672dd59e5", null ],
    [ "DetermineCapacity", "dc/d7a/structEngine.html#a52bc59187dac3f64c963fa824acee1b3", null ],
    [ "GetAircraftTypeText", "dc/d7a/structEngine.html#a00fae8843636a4b889c9998c7e57182b", null ],
    [ "GetCost", "dc/d7a/structEngine.html#a1c33f74d5096a73bdeed4f086398f89e", null ],
    [ "GetDefaultCargoType", "dc/d7a/structEngine.html#a06eeac4198ff3a0976f65f5776ae3a20", null ],
    [ "GetDisplayDefaultCapacity", "dc/d7a/structEngine.html#a381f1ab77d99cee821172a16994c23d6", null ],
    [ "GetDisplayMaxSpeed", "dc/d7a/structEngine.html#a3dff0f365c18125f68a49425469be6ac", null ],
    [ "GetDisplayMaxTractiveEffort", "dc/d7a/structEngine.html#ad41adc37c9a7823857f8eeaea153e254", null ],
    [ "GetDisplayWeight", "dc/d7a/structEngine.html#a5f8c94e86efab5f88271488568580660", null ],
    [ "GetGRF", "dc/d7a/structEngine.html#a7de14572110ba051de0384c5f4cd6d51", null ],
    [ "GetGRFID", "dc/d7a/structEngine.html#a16090398712332ef93a82c1ecdb83adc", null ],
    [ "GetLifeLengthInDays", "dc/d7a/structEngine.html#a8a88134b1f9afe4ea7a710dd63cd44f7", null ],
    [ "GetPower", "dc/d7a/structEngine.html#a022d2858d65c46152ea7e591744b5d7b", null ],
    [ "GetRange", "dc/d7a/structEngine.html#a2538f4743407083ce7f3751adcc13a5d", null ],
    [ "GetRunningCost", "dc/d7a/structEngine.html#aae265860fae4300e9c52cb1460ce6ce1", null ],
    [ "IsEnabled", "dc/d7a/structEngine.html#a65e1771c2f4130e240fd3adc5acfff94", null ],
    [ "IsGroundVehicle", "dc/d7a/structEngine.html#af8b3786a26b8cfa5c8fcbb07dd63a5d0", null ],
    [ "IsHidden", "dc/d7a/structEngine.html#ad3f6f1c9572f4da9e5e2446b8cc57fcf", null ],
    [ "age", "dc/d7a/structEngine.html#a774c8dc73e72e61488bf2df77614e4d5", null ],
    [ "air", "dc/d7a/structEngine.html#a501578c0d30caecbe69845b279873203", null ],
    [ "company_avail", "dc/d7a/structEngine.html#a526a95b6877ac739b1996a9dc48750c0", null ],
    [ "company_hidden", "dc/d7a/structEngine.html#aab7027bde57e9b911d3420abf8b66ed4", null ],
    [ "duration_phase_1", "dc/d7a/structEngine.html#aa60a83eecdaf41c3c2d5edccb0d70b21", null ],
    [ "duration_phase_2", "dc/d7a/structEngine.html#a3c6b2b4d7355661d15162ac65ecce5c6", null ],
    [ "duration_phase_3", "dc/d7a/structEngine.html#a1c4fceae50b3916128637901fc5cd92e", null ],
    [ "flags", "dc/d7a/structEngine.html#a1b255f2c3ac776878bf07dfe62bde8fa", null ],
    [ "grf_prop", "dc/d7a/structEngine.html#a097507d45f154b151c037c6270fd9538", null ],
    [ "info", "dc/d7a/structEngine.html#a3a37d8925cec731652ea1a765a9e4418", null ],
    [ "intro_date", "dc/d7a/structEngine.html#a654ec470652980a36b27d65a8a047a6a", null ],
    [ "list_position", "dc/d7a/structEngine.html#a884deadcbc25c4ccde65d2249ed60c46", null ],
    [ "name", "dc/d7a/structEngine.html#af7f19be35b23ebf71e7e8e128eec14d2", null ],
    [ "original_image_index", "dc/d7a/structEngine.html#a6b28f415ebf7b1f355752e54be899def", null ],
    [ "overrides", "dc/d7a/structEngine.html#a10b74e49b2c03b66ccf8c593e20874de", null ],
    [ "overrides_count", "dc/d7a/structEngine.html#a9ff859a56abc6b5c316d243de90b6539", null ],
    [ "preview_asked", "dc/d7a/structEngine.html#abc68640c5bac2af46b0aae35aaea7fcc", null ],
    [ "preview_company", "dc/d7a/structEngine.html#a6f84d69a5a7d565f6b9392cef1c0c3da", null ],
    [ "preview_wait", "dc/d7a/structEngine.html#abcac8217e7d3ac7d3f489d4e66beef8a", null ],
    [ "rail", "dc/d7a/structEngine.html#a5c61ada4dd855262c12da2b18c069df1", null ],
    [ "reliability", "dc/d7a/structEngine.html#a9fde4f4bb8db73143a9c56e706ff9af3", null ],
    [ "reliability_final", "dc/d7a/structEngine.html#a4f8493812d98ec2dfeda86f64a2c9044", null ],
    [ "reliability_max", "dc/d7a/structEngine.html#a1874dbaa5f31daa8566c1c03ba4f56a1", null ],
    [ "reliability_spd_dec", "dc/d7a/structEngine.html#a9c27ba0e0c7853da64fcceefa7536ca4", null ],
    [ "reliability_start", "dc/d7a/structEngine.html#adea7f58812a00c3d5e175b8f98968082", null ],
    [ "road", "dc/d7a/structEngine.html#afb6d9ec586fb5f8ec80cf85e33f387fa", null ],
    [ "ship", "dc/d7a/structEngine.html#adc365bd1373954fb490decf85208ae93", null ],
    [ "type", "dc/d7a/structEngine.html#a67286860649162c8eddee176ed869f37", null ],
    [ "u", "dc/d7a/structEngine.html#ad3487a5a9d5d14c0f4f84eb5d15e4474", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/dc/d7a/structEngine.js <==
var structEngine =
[
    [ "EngineTypeFilter", "dc/d77/structEngine_1_1EngineTypeFilter.html", "dc/d77/structEngine_1_1EngineTypeFilter" ],
    [ "Engine", "dc/d7a/structEngine.html#a8c98683b0a3aa28d8ab72a8bcd0d52f2", null ],
    [ "Engine", "dc/d7a/structEngine.html#ab982bcd16c14f30e70dfd0135b879cd4", null ],
    [ "~Engine", "dc/d7a/structEngine.html#a8ef7030a089ecb30bbfcb9e43094717a", null ],
    [ "CanCarryCargo", "dc/d7a/structEngine.html#ae398bf3ad2c3ba475880fc7672dd59e5", null ],
    [ "DetermineCapacity", "dc/d7a/structEngine.html#abee09db13e0d84ad02fdfb65ec7a836f", null ],
    [ "GetAircraftTypeText", "dc/d7a/structEngine.html#a00fae8843636a4b889c9998c7e57182b", null ],
    [ "GetCost", "dc/d7a/structEngine.html#a1c33f74d5096a73bdeed4f086398f89e", null ],
    [ "GetDefaultCargoType", "dc/d7a/structEngine.html#a06eeac4198ff3a0976f65f5776ae3a20", null ],
    [ "GetDisplayDefaultCapacity", "dc/d7a/structEngine.html#a2a9ceb4ad4d7389553b7a40ac5090b7f", null ],
    [ "GetDisplayMaxSpeed", "dc/d7a/structEngine.html#a3dff0f365c18125f68a49425469be6ac", null ],
    [ "GetDisplayMaxTractiveEffort", "dc/d7a/structEngine.html#ad41adc37c9a7823857f8eeaea153e254", null ],
    [ "GetDisplayWeight", "dc/d7a/structEngine.html#a5f8c94e86efab5f88271488568580660", null ],
    [ "GetGRF", "dc/d7a/structEngine.html#a7de14572110ba051de0384c5f4cd6d51", null ],
    [ "GetGRFID", "dc/d7a/structEngine.html#a16090398712332ef93a82c1ecdb83adc", null ],
    [ "GetLifeLengthInDays", "dc/d7a/structEngine.html#a8a88134b1f9afe4ea7a710dd63cd44f7", null ],
    [ "GetPower", "dc/d7a/structEngine.html#a022d2858d65c46152ea7e591744b5d7b", null ],
    [ "GetRange", "dc/d7a/structEngine.html#a2538f4743407083ce7f3751adcc13a5d", null ],
    [ "GetRunningCost", "dc/d7a/structEngine.html#aae265860fae4300e9c52cb1460ce6ce1", null ],
    [ "IsEnabled", "dc/d7a/structEngine.html#a65e1771c2f4130e240fd3adc5acfff94", null ],
    [ "IsGroundVehicle", "dc/d7a/structEngine.html#af8b3786a26b8cfa5c8fcbb07dd63a5d0", null ],
    [ "IsHidden", "dc/d7a/structEngine.html#ad7764547f70f8809a8f80e4d9a2e2875", null ],
    [ "IterateType", "dc/d7a/structEngine.html#add00548be97dcc4e925e2da1f81a2775", null ],
    [ "age", "dc/d7a/structEngine.html#a774c8dc73e72e61488bf2df77614e4d5", null ],
    [ "air", "dc/d7a/structEngine.html#a501578c0d30caecbe69845b279873203", null ],
    [ "company_avail", "dc/d7a/structEngine.html#a526a95b6877ac739b1996a9dc48750c0", null ],
    [ "company_hidden", "dc/d7a/structEngine.html#aab7027bde57e9b911d3420abf8b66ed4", null ],
    [ "duration_phase_1", "dc/d7a/structEngine.html#aa60a83eecdaf41c3c2d5edccb0d70b21", null ],
    [ "duration_phase_2", "dc/d7a/structEngine.html#a3c6b2b4d7355661d15162ac65ecce5c6", null ],
    [ "duration_phase_3", "dc/d7a/structEngine.html#a1c4fceae50b3916128637901fc5cd92e", null ],
    [ "flags", "dc/d7a/structEngine.html#a1b255f2c3ac776878bf07dfe62bde8fa", null ],
    [ "grf_prop", "dc/d7a/structEngine.html#a097507d45f154b151c037c6270fd9538", null ],
    [ "info", "dc/d7a/structEngine.html#a3a37d8925cec731652ea1a765a9e4418", null ],
    [ "intro_date", "dc/d7a/structEngine.html#a654ec470652980a36b27d65a8a047a6a", null ],
    [ "list_position", "dc/d7a/structEngine.html#a884deadcbc25c4ccde65d2249ed60c46", null ],
    [ "name", "dc/d7a/structEngine.html#ae5244ecb00500ccff2f68ef0c6a42472", null ],
    [ "original_image_index", "dc/d7a/structEngine.html#a6b28f415ebf7b1f355752e54be899def", null ],
    [ "overrides", "dc/d7a/structEngine.html#a10b74e49b2c03b66ccf8c593e20874de", null ],
    [ "overrides_count", "dc/d7a/structEngine.html#a9ff859a56abc6b5c316d243de90b6539", null ],
    [ "preview_asked", "dc/d7a/structEngine.html#abc68640c5bac2af46b0aae35aaea7fcc", null ],
    [ "preview_company", "dc/d7a/structEngine.html#a851581a1f0b4191710c054a0cbc2f1e2", null ],
    [ "preview_wait", "dc/d7a/structEngine.html#abcac8217e7d3ac7d3f489d4e66beef8a", null ],
    [ "rail", "dc/d7a/structEngine.html#a5c61ada4dd855262c12da2b18c069df1", null ],
    [ "reliability", "dc/d7a/structEngine.html#a9fde4f4bb8db73143a9c56e706ff9af3", null ],
    [ "reliability_final", "dc/d7a/structEngine.html#a4f8493812d98ec2dfeda86f64a2c9044", null ],
    [ "reliability_max", "dc/d7a/structEngine.html#a1874dbaa5f31daa8566c1c03ba4f56a1", null ],
    [ "reliability_spd_dec", "dc/d7a/structEngine.html#a9c27ba0e0c7853da64fcceefa7536ca4", null ],
    [ "reliability_start", "dc/d7a/structEngine.html#adea7f58812a00c3d5e175b8f98968082", null ],
    [ "road", "dc/d7a/structEngine.html#afb6d9ec586fb5f8ec80cf85e33f387fa", null ],
    [ "ship", "dc/d7a/structEngine.html#adc365bd1373954fb490decf85208ae93", null ],
    [ "type", "dc/d7a/structEngine.html#a67286860649162c8eddee176ed869f37", null ],
    [ "u", "dc/d7a/structEngine.html#a4231b35d417dedd9d9fd05ca306959dc", null ]
];
